# Curso LaTeX IAS #


El presente repositorio contiene ejemplos completos de LaTeX y secciones de código útiles durante el curso, así como links útiles.

**El curso  ha sido especialmente diseñado para la rama estudiantil Industrial Applications Society del IEEE** por el su servido Gerardo Marx Chávez-Campos de la Maestría en Ciencias en Ingeniería Electrónica.

# Contenido general del curso #

  * Instalación y distribuciones de LaTeX
  * GUIs básicos y avanzados
  * Primer documento
  * Tipos de documentos y paquetes
  * Ecuaciones, Figuras y Notas
  * Tablas y Matrices
  * Referencias bibliográficas
  * Datos CSV
  * Gráficas de datos
  * Circuitos eléctricos(spice) 
	
-------------------------------------------------------------------------------



# Instalación y distribuciones de LaTeX #

En el siguiente vídeo se puede observar la forma de instalar una de las distribuciones más básicas y usadas de LaTeX en diferentes sistemas operativos: [Instalación de LaTeX con MikTeX](https://www.youtube.com/watch?v=4w9AjLqSjo0 "youtube")

Aquí puedes encontrar los instaladores de [MikTeX](https://miktex.org/), así como la liga del sistema en línea [Overleaf](https://www.overleaf.com/login); si entras con el correo de **IEEE** obtendrás ciertos beneficios en tu cuenta y espacio de *hosting*.

# GUIs básicos y avanzados #

LaTeX es un sistema de preparación de documentos. El sistema utiliza un archivo fuente con extesión `.tex`, que después es usado para compilar (con `pdflatex`) y producir un archivo de salida (PDF). Por lo tanto el sistema de preparación de documentos de LaTeX es un lenguaje de programación . Por lo tanto, como en cualquier lenguaje de programación, los IDEs (*Integrated Development Eviroments) son esenciales para facilitar la labor al usuario. 

En ese sentido, podemos crear cosas archivos fuente con cualquier editor de texto y después compilarlo. Sin embargo, para facilitarnos la vida podemos en una primera instancia utilizar IDEs dependiendo del grado de uso que le demos al sistema. Los más básicos son *TeXworks* y *Texstudio*. Por otro lado, entornos más avanzados son *Sublime*, *Vim* y *Emacs*. Éste último es el más potente y a la vez difícil de usar, pero el más extensible y configurable, con la posibilidad de no solo ser usado en sistemas como LaTeX, sino en gran variedad de lenguajes de programación.

![emacs](https://poesiabinaria.net/wp-content/uploads/2017/09/xemacs-1280x800.png.pagespeed.ic.LSv4PWuauW.png "wow")


# Ejemplos y guías #

## Mi primer documento ##

``` tex
\documentclass{article}
\begin{document}
	Hello \LaTeX{}
\end{document}
```

## Estructura de un reporte ##

![Anatomy](https://cdnapisec.kaltura.com/p/2103181/sp/210318100/thumbnail/entry_id/1_cebwj9vf/version/100011/width/0/height/0)

Existen una gran variedad de tipos de reportes, entre ellos se encuentran los reportes técnicos en ingeniería.

De acuerdo con [^1] un reporte técnico es un informe de investigación científica o tecnológica que aborda un tema de investigación o desarrollo. Son válidos trabajos de investigación en general, recopilación de soluciones existentes o desarrollo de aplicaciones novedosas. El reporte técnico de investigación es un documento que se utiliza para informar tanto los procedimientos como los resultados de una investigación en forma concisa y dentro de una estructura lógica, **el objetivo del informe consiste en presentar la investigación y no la personalidad del autor**; por eso el tono debe ser impersonal y **nunca se emplea la primera persona**.

La *universidad de Sheffield* cuenta con vídeo que describe brevemente la *anatomía de un reporte técnico de ingeniería*, altamente recomendable: [Report's anatomy video](https://digitalmedia.sheffield.ac.uk/media/Anatomy+of+a+Technical+Engineering+Report/1_cebwj9vf).

Entonces, la estructura básica del reporte, comúnmente es:
  * Título/portada
  * Soporte teórico
  * Procedimiento/metodología
  * Discusión/Resultados
  * Conclusiones y comentarios
  * Bibliografía

[^1]: https://www.google.com/url?sa=t&rct=j&q=&esrc=s&source=web&cd=&ved=2ahUKEwiv_bXPvtLsAhUJgK0KHU29BZQQFjABegQIARAC&url=http%3A%2F%2Fwww.unsis.edu.mx%2Fconvocatorias%2FREPORTE_TECNICO.doc&usg=AOvVaw2XT9jC3BmL4OTTTcZkCfaL

## Creando la estructura  ##

``` tex
\documentclass{article}
\usepackage[spanish]{babel}
\usepackage[utf8]{inputenc}
\usepackage{blindtext}
\usepackage{amsmath}
\usepackage{graphicx}
\title{Proyecto de Investigación Aplicado a Algo Interesante}
\author{Gerardo M. Chávez-Campos}
\begin{document}
\maketitle
\section{Introducción}
\blindtext[2]
\section{Materiales y métodos}
En \eqref{fourier} siguiente se muestra la 
transformada de Fourier.
\begin{equation}
    f(x)=\int_0^{\infty}x sin(\omega)\label{fourier}
\end{equation}
En \eqref{recta} se muestra la formula para ....
\begin{equation}
    y=mx+b\label{recta}
\end{equation}

\blindtext[8]
\section{Resultados}
\blindtext[4]
\begin{figure}
    \centering
    \includegraphics[width=2.5in]{metodologia.jpg}
    \caption{Caption}
    \label{fig:my_label}
\end{figure}

\section{Conclusiones}
\blindtext[1]
\end{document}
```

